==> dl.php?src=linea21_1_6.zip: linea21/languages/es/lang_news.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage es
 * @author Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['news']['section'] = "noticias";

/*	nommage des modules
 *  	*/
$lang['news']['name']='noticia';
$lang['news']['confirm_add'] = "Noticia agregada correctamente";
$lang['news']['confirm_mod'] = "Noticia actualizada correctamente";
$lang['news']['confirm_sup'] = "Noticia eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['news']['add']= 'Añadir nueva '.$lang['news']['name'];
$lang['news']['mod']= 'Editar '.$lang['news']['name'];
$lang['news']['sup']= 'Eliminar '.$lang['news']['name'];
$lang['news']['det']= ucfirst($lang['news']['name']). ' detalles';
$lang['news']['list']= 'Ver '.$lang['news']['name'];


/*	nommage rubrique add / mod /det
 *  	*/
$lang['news']['add_title']='Añadir valores a la nueva '.$lang['news']['name'];
$lang['news']['mod_title']='Editar valores de la '.$lang['news']['name'];
$lang['news']['recap_commment']='sin comentarios';


/*	check integrité des données
 *  	*/
$lang['news']['no_scale']='La escala es requerida';
$lang['news']['no_level']='El nivel es requerido';
$lang['news']['no_theme']='El área es requerida';
$lang['news']['no_title']='El título es requerido';
$lang['news']['no_body']='El cuerpo es requerido';
$lang['news']['no_header']='El encabezado es requerido';



/*	nommage élément rubrique
 *  	*/
$lang['news']['title']='título';
$lang['news']['header']= 'encabezado';
$lang['news']['body']= 'cuerpo';
$lang['news']['theme']='área asociada';
$lang['news']['level']='nivel asociado';
$lang['news']['scale']='escala asociada';
$lang['news']['statut']='estado';
$lang['news']['author']='autor';


/*	nommage quickbox
 *  	*/
$lang['news']['qb_titleadd']=' noticias agregadas recientemente';
$lang['news']['qb_titlemod']=' noticias modificadas recientemente';
$lang['news']['qb_titlesup']=' noticias eliminadas recientemente';
$lang['news']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/
$lang['news']['nb_total']='noticia(s) en la base de datos.';
$lang['news']['statut_filter']='Mostrar por estados';
$lang['news']['all']='Mostrar lista';
$lang['news']['noresult']='No existen noticias con este criterio ';


/*	public
 *  	*/

$lang['news']['name2']='noticias';
$lang['news']['next_news']='noticia siguiente';
$lang['news']['prev_news']='noticia anterior';
/*	rubrique d'aide
 *  	*/
$lang['news']['help_add1']='Para añadir una noticia, inserte la información requerida en el formulario.';
$lang['news']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['news']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea hacer cambios';


$lang['news']['help_list1']='Para mas información haga click en el título de la noticia.';
$lang['news']['help_list2']="Para eliminar una noticia, haga click en el icono 'eliminar noticia'.";
$lang['news']['help_list3']="Para editar una noticia, haga click en el icono 'editar noticia'.";
$lang['news']['help_list4']='Para visualizar las noticias según su estado, mostrar por estados.';
$lang['news']['help_list5']='Para añadir una noticia, haga click en "añadir nueva noticia".';
$lang['news']['help_list6']="Si desea realizar búsquedas dentro del módulo 'noticias', haga click en 'buscar'.";


$lang['news']['help_mod1']='Para editar una noticia, complete la información requerida en el formulario.';
$lang['news']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['news']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['news']['help_det1']="Para eliminar una noticia, haga click en el icono 'eliminar noticia'.";
$lang['news']['help_det2']="Para editar una noticia, haga click en el icono 'editar noticia'.";

$lang['news']['help_sup1']="Para abortar la eliminación, haga click  en 'cancelar'.";
?>

==> dl.php?src=linea21_1_8.zip: linea21/languages/es/lang_news.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['news']['section'] = "noticias";

/*	nommage des modules
 *  	*/
$lang['news']['name']='noticia';
$lang['news']['confirm_add'] = "Noticia agregada correctamente";
$lang['news']['confirm_mod'] = "Noticia actualizada correctamente";
$lang['news']['confirm_sup'] = "Noticia eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['news']['add']= 'Añadir nueva '.$lang['news']['name'];
$lang['news']['mod']= 'Editar '.$lang['news']['name'];
$lang['news']['sup']= 'Eliminar '.$lang['news']['name'];
$lang['news']['det']= ucfirst($lang['news']['name']). ' detalles';
$lang['news']['list']= 'Ver '.$lang['news']['name'];


/*	nommage rubrique add / mod /det
 *  	*/
$lang['news']['add_title']='Añadir valores a la nueva '.$lang['news']['name'];
$lang['news']['mod_title']='Editar valores de la '.$lang['news']['name'];
$lang['news']['recap_commment']='sin comentarios';


/*	check integrité des données
 *  	*/
$lang['news']['no_scale']='La escala es requerida';
$lang['news']['no_theme']='El área es requerida';
$lang['news']['no_title']='El título es requerido';
$lang['news']['no_body']='El cuerpo es requerido';
$lang['news']['no_header']='El encabezado es requerido';



/*	nommage élément rubrique
 *  	*/
$lang['news']['title']='título';
$lang['news']['header']= 'encabezado';
$lang['news']['body']= 'cuerpo';
$lang['news']['theme']='área asociada';
$lang['news']['scale']='escala asociada';
$lang['news']['statut']='estado';
$lang['news']['author']='autor';


/*	nommage quickbox
 *  	*/
$lang['news']['qb_titleadd']=' noticias agregadas recientemente';
$lang['news']['qb_titlemod']=' noticias modificadas recientemente';
$lang['news']['qb_titlesup']=' noticias eliminadas recientemente';
$lang['news']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/
$lang['news']['nb_total']='noticia(s) en la base de datos.';
$lang['news']['statut_filter']='Mostrar por estados';
$lang['news']['all']='Mostrar lista';
$lang['news']['noresult']='No existen noticias con este criterio ';


/*	public
 *  	*/

$lang['news']['name2']='noticias';
$lang['news']['next_news']='noticia siguiente';
$lang['news']['prev_news']='noticia anterior';
/*	rubrique d'aide
 *  	*/
$lang['news']['help_add1']='Para añadir una noticia, inserte la información requerida en el formulario.';
$lang['news']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['news']['help_add3']='Validado el resumen, haga click en "revisar valores" si desea hacer cambios';


$lang['news']['help_list1']='Para mas información haga click en el título de la noticia.';
$lang['news']['help_list2']="Para eliminar una noticia, haga click en el icono 'eliminar noticia'.";
$lang['news']['help_list3']="Para editar una noticia, haga click en el icono 'editar noticia'.";
$lang['news']['help_list4']='Para visualizar las noticias según su estado, mostrar por estados.';
$lang['news']['help_list5']='Para añadir una noticia, haga click en "añadir nueva noticia".';
$lang['news']['help_list6']="Si desea realizar búsquedas dentro del módulo 'noticias', haga click en 'buscar'.";


$lang['news']['help_mod1']='Para editar una noticia, complete la información requerida en el formulario.';
$lang['news']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['news']['help_mod3']='Validado el resumen, haga click en "revisar valores" si desea realizar cambios.';


$lang['news']['help_det1']="Para eliminar una noticia, haga click en el icono 'eliminar noticia'.";
$lang['news']['help_det2']="Para editar una noticia, haga click en el icono 'editar noticia'.";

$lang['news']['help_sup1']="Para abortar la eliminación, haga click  en 'cancelar'.";
?>
